@@ -33,17 +33,13 @@ def utfme(elem):
         for e in elem:
             res.append(utfme(e))
         elem = res
+        if isinstance(elem, types.TupleType):
+            elem = tuple(elem)
     elif isinstance(elem, basestring):
         elem = elem.encode('utf-8')
     return elem
 
 
-def normalize_dir(directory):
-    while '//' in directory:
-        directory = directory.replace('//', '/')
-    return directory.rstrip('/')
-
-
 class TRMaid(object):
 
     def __init__(self, config_file=CONF_FILE_FULL, verbose=False):
@@ -108,10 +104,6 @@ class TRMaid(object):
             print '=>', json.dumps(result, indent=2)
         return result
 
-    def conf_get(self, section, item, cast=None):
-        if section in self.conf and item in self.conf[section]:
-            return self.conf[section][item]
-
     def handle_session(self):
         if 'session' not in self.conf:
             return self.msg('No [session] section')
@@ -250,7 +242,7 @@ class TRMaid(object):
             return
 
         sections = self.conf.get('location', [])
-        location = normalize_dir(tor['downloadDir'])
+        location = os.path.normpath(tor['downloadDir'])
         if location in sections:
             self.handle_torrent_section(tor, 'location', location)
             return
@@ -263,8 +255,8 @@ class TRMaid(object):
         conf = self.conf.get(section, {}).get(subsection, {})
         for key in ['download-dir', 'location']:
             if key in conf:
-                correct = normalize_dir(conf.get(key))
-                current = normalize_dir(tor['downloadDir'])
+                correct = os.path.normpath(conf.get(key))
+                current = os.path.normpath(tor['downloadDir'])
                 if current != correct:
                     self.verbose_func(
                         self.rpc.torrent_set_location, tor['id'], correct)
@@ -407,8 +399,9 @@ class TRMaid(object):
             if rdskey:
                 self.rds.ltrim(rdskey, 0, 1000)
             set_req = self.get_torrent_set_args(section, subsection)
-            set_req['ids'] = ids
-            res = self.verbose_func(self.rpc.torrent_set, set_req)
+            if set_req:
+                set_req['ids'] = ids
+                self.verbose_func(self.rpc.torrent_set, set_req)
 
     def handle_redis(self):
         def links(queue):
